summaryrefslogtreecommitdiff
path: root/src/mongo/db/storage/index_entry_comparison.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/mongo/db/storage/index_entry_comparison.h')
-rw-r--r--src/mongo/db/storage/index_entry_comparison.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/mongo/db/storage/index_entry_comparison.h b/src/mongo/db/storage/index_entry_comparison.h
index 5765ad6d6bd..ea2eb005e9b 100644
--- a/src/mongo/db/storage/index_entry_comparison.h
+++ b/src/mongo/db/storage/index_entry_comparison.h
@@ -42,10 +42,10 @@ namespace mongo {
* and a disk location.
*/
struct IndexKeyEntry {
- IndexKeyEntry(const BSONObj& key, DiskLoc loc) :key(key), loc(loc) {}
+ IndexKeyEntry(const BSONObj& key, RecordId loc) :key(key), loc(loc) {}
BSONObj key;
- DiskLoc loc;
+ RecordId loc;
};
/**
@@ -66,7 +66,7 @@ namespace mongo {
* otherwise.
*
* IndexKeyEntries are compared lexicographically field by field in the BSONObj, followed by
* the DiskLoc. Either lhs or rhs (but not both) can be a query object returned by
* makeQueryObject(). See makeQueryObject() for a description of how its arguments affect
* the outcome of the comparison.
*/
@@ -66,7 +66,7 @@ namespace mongo {
*
* IndexKeyEntries are compared lexicographically field by field in the BSONObj, followed by
- * the DiskLoc. Either lhs or rhs (but not both) can be a query object returned by
+ * the RecordId. Either lhs or rhs (but not both) can be a query object returned by
* makeQueryObject(). See makeQueryObject() for a description of how its arguments affect
* the outcome of the comparison.